API docs for “spamfighter.txjsonrpc.netstring.jsonrpc”

# Module s.t.n.jsonrpc

Part of spamfighter.txjsonrpc.netstring View Source

A generic resource for publishing objects via JSON-RPC.

API Stability: semi-stable

Maintainer: Duncan McGreggor

Class | JSONRPC | A protocol that implements JSON-RPC.
Class | JSONRPCIntrospection | Implement the JSON-RPC Introspection API.
Function | addIntrospection | Add Introspection support to an JSONRPC server.
Class | QueryProtocol | Undocumented
Class | QueryFactory | Undocumented
Class | Proxy | A Proxy for making remote JSON-RPC calls.
Class | RPCFactory | Undocumented

def addIntrospection(jsonrpc): (source)
Add Introspection support to an JSONRPC server.

Parameters | jsonrpc | The jsonrpc server to add Introspection support to.